pub struct IdentityTemplate {
pub hostname_template: Option<String>,
pub username_template: Option<String>,
}Expand description
Templates rendered (Jinja2-compatible) at admission to derive consumer identity
when a BackupConfig doesn’t override. ADR 3.2/4.2.
Fields
hostname_template: Option<String>Tera/Jinja2 template for the kopia identity hostname, rendered at admission
(e.g. {{ .Namespace }}). ADR 3.2/4.2.
username_template: Option<String>Tera/Jinja2 template for the kopia identity username, rendered at admission
(e.g. {{ .Namespace }}-{{ .ConfigName }}). ADR 3.2/4.2.