pub enum RestoreTarget {
Pvc(PvcTemplate),
PvcRef(ObjectRef),
}Expand description
Where to restore to. Externally-tagged; exactly one variant when present. ADR 3.6.
Wire shape: target: { pvc: {...} } or { pvcRef: {...} }. Omitting target
entirely (modeled as Option<RestoreTarget> on the spec) is passive mode.
Variants
Implementations
Sourceimpl RestoreTarget
impl RestoreTarget
Sourcepub fn kind_str(&self) -> &'static str
pub fn kind_str(&self) -> &'static str
Stable discriminant string for status/metrics.
use kopiur_api::common::ObjectRef;
use kopiur_api::restore::RestoreTarget;
let into_existing = RestoreTarget::PvcRef(ObjectRef { name: "data".into(), namespace: None });
assert_eq!(into_existing.kind_str(), "PvcRef");
// Externally tagged: `{ pvc: {...} }` selects the create-PVC variant.
let created: RestoreTarget =
serde_json::from_value(serde_json::json!({ "pvc": { "name": "restored" } })).unwrap();
assert_eq!(created.kind_str(), "Pvc");Trait Implementations
Sourceimpl Clone for RestoreTarget
impl Clone for RestoreTarget
Sourcefn clone(&self) -> RestoreTarget
fn clone(&self) -> RestoreTarget
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RestoreTarget
impl Debug for RestoreTarget
Sourceimpl<'de> Deserialize<'de> for RestoreTarget
impl<'de> Deserialize<'de> for RestoreTarget
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RestoreTarget
impl JsonSchema for RestoreTarget
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RestoreTarget
impl PartialEq for RestoreTarget
Sourceimpl Serialize for RestoreTarget
impl Serialize for RestoreTarget
impl StructuralPartialEq for RestoreTarget