pub struct MoverDefaults {
pub security_context: Option<SecurityContext>,
pub pod_security_context: Option<PodSecurityContext>,
pub resources: Option<ResourceRequirements>,
pub cache: Option<CacheDefaults>,
pub scratch: Option<ScratchDefaults>,
pub node_selector: Option<BTreeMap<String, String>>,
pub tolerations: Option<Vec<Toleration>>,
pub affinity: Option<Affinity>,
pub source_colocation: Option<SourceColocation>,
pub ttl_seconds_after_finished: Option<i64>,
pub throttle: Option<Throttle>,
}Expand description
Repository-wide mover defaults inherited by every mover, overridable per-recipe via mover.
Fields
security_context: Option<SecurityContext>Container security-context base for every mover.
pod_security_context: Option<PodSecurityContext>Pod security-context base (notably fsGroup) for every mover.
resources: Option<ResourceRequirements>Resource requests/limits base for the mover container.
cache: Option<CacheDefaults>kopia cache defaults for every mover.
scratch: Option<ScratchDefaults>Defaults for the deep-verification scratch (restore-test) volume.
node_selector: Option<BTreeMap<String, String>>Pod nodeSelector for every mover.
tolerations: Option<Vec<Toleration>>Pod tolerations for every mover.
affinity: Option<Affinity>Pod affinity for every mover.
source_colocation: Option<SourceColocation>How a mover co-locates with its RWO PVC’s node; defaults to SourceColocationMode::Auto.
ttl_seconds_after_finished: Option<i64>Job.spec.ttlSecondsAfterFinished for every mover Job so finished Jobs self-GC.
throttle: Option<Throttle>Repository throttle limits applied by every mover after it connects.